@@ -39,7 +39,7 @@ def version():
     """
     print('SAT-X The constraint modeling language for SAT solvers http://www.peqnp.com')
     print('Copyright (c) 2012-2021 Oscar Riveros. all rights reserved.')
-    print('oscar.riveros@pe.science')
+    print('oscar.riveros@peqnp.science')
 
 
 def check_engine():
@@ -133,12 +133,11 @@ def subset(lst, k, empty=None, complement=False):
     return subset_
 
 
-def vector(bits=None, size=None, signed=True, is_gaussian=False, is_rational=False):
+def vector(bits=None, size=None, is_gaussian=False, is_rational=False):
     """
     A vector of integers.
     :param bits: The bit bits for each integer.
     :param size: The bits of the vector.
-    :param signed: integer or integer components.
     :param is_gaussian: Indicate of is a Gaussian Integers vector.
     :param is_rational: Indicate of is a Rational vector.
     :return: An instance of vector.
@@ -146,20 +145,19 @@ def vector(bits=None, size=None, signed=True, is_gaussian=False, is_rational=Fal
     global csp
     check_engine()
     if is_rational:
-        return [rational(signed=signed) for _ in range(size)]
+        return [rational() for _ in range(size)]
     if is_gaussian:
-        return [gaussian(signed=signed) for _ in range(size)]
-    array_ = csp.array(signed=signed, size=bits, dimension=size)
+        return [gaussian() for _ in range(size)]
+    array_ = csp.array(size=bits, dimension=size)
     csp.variables += array_
     return array_
 
 
-def matrix(bits=None, dimensions=None, signed=True, is_gaussian=False, is_rational=False):
+def matrix(bits=None, dimensions=None, is_gaussian=False, is_rational=False):
     """
     A matrix of integers.
     :param bits: The bit bits for each integer.
     :param dimensions: An tuple with the dimensions for the Matrix (n, m).
-    :param signed: integer or integer components.
     :param is_gaussian: Indicate of is a Gaussian Integers vector.
     :param is_rational: Indicate of is a Rational Matrix.
     :return: An instance of Matrix.
@@ -491,39 +489,29 @@ def index(ith, data):
     return csp.variables[-1]
 
 
-def gaussian(x=None, y=None, signed=True):
+def gaussian(x=None, y=None):
     """
     Create a gaussian integer from (x+yj).
     :param x: real
     :param y: imaginary
-    :param signed: integer or integer components, if x and y not provided.
     :return: (x+yj)
     """
     check_engine()
-    if signed:
-        if x is None and y is None:
-            return Gaussian(integer(), integer())
-    else:
-        if x is None and y is None:
-            return Gaussian(integer(), integer())
+    if x is None and y is None:
+        return Gaussian(integer(), integer())
     return Gaussian(x, y)
 
 
-def rational(x=None, y=None, signed=True):
+def rational(x=None, y=None):
     """
     Create a rational x / y.
     :param x: numerator
     :param y: denominator
-    :param signed: integer or integer components, if x and y not provided.
     :return: x / y
     """
     check_engine()
-    if signed:
-        if x is None and y is None:
-            return Rational(integer(), integer())
-    else:
-        if x is None and y is None:
-            return Rational(integer(), integer())
+    if x is None and y is None:
+        return Rational(integer(), integer())
     return Rational(x, y)
 
 
@@ -568,6 +556,10 @@ def hess_sequence(n, oracle, fast=False, cycles=1, target=0, seq=None):
     :param seq: External sequence if not set default sequence is used (1..n)
     :return optimized sequence.
     """
+    import hashlib
+
+    db = []
+
     if seq is not None:
         xs = seq
     else:
@@ -575,8 +567,7 @@ def hess_sequence(n, oracle, fast=False, cycles=1, target=0, seq=None):
     glb = oracle(xs) + 1
     opt = xs[:]
 
-    def __inv(a, b, xs):
-        i, j = min(a, b), max(a, b)
+    def __inv(i, j, xs):
         while i < j:
             xs[i], xs[j] = xs[j], xs[i]
             i += 1
@@ -590,7 +581,13 @@ def hess_sequence(n, oracle, fast=False, cycles=1, target=0, seq=None):
                 anchor = glb
                 for i in range(len(xs) - 1):
                     for j in range(i + 1, len(xs)):
-                        __inv(i, j, xs)
+                        key = hashlib.sha256(''.join(map(str, [min(i, j)] + xs + [max(i, j)]))).hexdigest()
+                        if key not in db:
+                            db.append(key)
+                            db.sort()
+                        else:
+                            continue
+                        __inv(min(i, j), max(i, j), xs)
                         loc = oracle(xs)
                         if loc < glb:
                             glb = loc
@@ -600,7 +597,7 @@ def hess_sequence(n, oracle, fast=False, cycles=1, target=0, seq=None):
                                 if top <= target:
                                     return opt
                         elif loc > glb:
-                            __inv(i, j, xs)
+                            __inv(min(i, j), max(i, j), xs)
                 if anchor == glb:
                     break
         else:
@@ -608,7 +605,13 @@ def hess_sequence(n, oracle, fast=False, cycles=1, target=0, seq=None):
                 anchor = glb
                 for i in range(len(xs)):
                     for j in range(len(xs)):
-                        __inv(i, j, xs)
+                        key = hashlib.sha256(''.join(map(str, [min(i, j)] + xs + [max(i, j)])).encode()).hexdigest()
+                        if key not in db:
+                            db.append(key)
+                            db.sort()
+                        else:
+                            continue
+                        __inv(min(i, j), max(i, j), xs)
                         loc = oracle(xs)
                         if loc < glb:
                             glb = loc
@@ -618,7 +621,7 @@ def hess_sequence(n, oracle, fast=False, cycles=1, target=0, seq=None):
                                 if top <= target:
                                     return opt
                         elif loc > glb:
-                            __inv(i, j, xs)
+                            __inv(min(i, j), max(i, j), xs)
                 if anchor == glb:
                     break
 
@@ -643,6 +646,10 @@ def hess_binary(n, oracle, fast=False, cycles=1, target=0, seq=None):
     :param seq: External sequence if not set default sequence is used (1..n)
     :return optimized sequence.
     """
+    import hashlib
+
+    db = []
+
     if seq is not None:
         xs = seq
     else:
@@ -666,7 +673,13 @@ def hess_binary(n, oracle, fast=False, cycles=1, target=0, seq=None):
                 anchor = glb
                 for i in range(len(xs) - 1):
                     for j in range(i + 1, len(xs)):
-                        __inv(i, j, xs)
+                        key = hashlib.sha256(bytes([min(i, j)] + xs + [max(i, j)])).hexdigest()
+                        if key not in db:
+                            db.append(key)
+                            db.sort()
+                        else:
+                            continue
+                        __inv(min(i, j), max(i, j), xs)
                         loc = oracle(xs)
                         if loc < glb:
                             glb = loc
@@ -676,7 +689,7 @@ def hess_binary(n, oracle, fast=False, cycles=1, target=0, seq=None):
                                 if top <= target:
                                     return opt
                         elif loc > glb:
-                            __inv(i, j, xs)
+                            __inv(min(i, j), max(i, j), xs)
                 if anchor == glb:
                     break
         else:
@@ -684,7 +697,13 @@ def hess_binary(n, oracle, fast=False, cycles=1, target=0, seq=None):
                 anchor = glb
                 for i in range(len(xs)):
                     for j in range(len(xs)):
-                        __inv(i, j, xs)
+                        key = hashlib.sha256(bytes([min(i, j)] + xs + [max(i, j)])).hexdigest()
+                        if key not in db:
+                            db.append(key)
+                            db.sort()
+                        else:
+                            continue
+                        __inv(min(i, j), max(i, j), xs)
                         loc = oracle(xs)
                         if loc < glb:
                             glb = loc
@@ -694,7 +713,7 @@ def hess_binary(n, oracle, fast=False, cycles=1, target=0, seq=None):
                                 if top <= target:
                                     return opt
                         elif loc > glb:
-                            __inv(i, j, xs)
+                            __inv(min(i, j), max(i, j), xs)
                 if anchor == glb:
                     break
     return opt
@@ -720,6 +739,10 @@ def hess_abstract(xs, oracle, f, g, log=None, fast=False, cycles=1, target=0):
     :param target: Any value less than this terminates the execution.
     :return optimized vector over the oracle over and f, g.
     """
+    import hashlib
+
+    db = []
+
     glb = oracle(xs) + 1
     opt = xs[:]
 
@@ -731,7 +754,13 @@ def hess_abstract(xs, oracle, f, g, log=None, fast=False, cycles=1, target=0):
                 anchor = glb
                 for i in range(len(xs) - 1):
                     for j in range(i + 1, len(xs)):
-                        f(i, j, xs)
+                        key = hashlib.sha256(bytes([min(i, j)] + xs + [max(i, j)])).hexdigest()
+                        if key not in db:
+                            db.append(key)
+                            db.sort()
+                        else:
+                            continue
+                        f(min(i, j), max(i, j), xs)
                         loc = oracle(xs)
                         if loc < glb:
                             glb = loc
@@ -743,7 +772,7 @@ def hess_abstract(xs, oracle, f, g, log=None, fast=False, cycles=1, target=0):
                                 if top <= target:
                                     return opt
                         elif loc > glb:
-                            g(i, j, xs)
+                            g(min(i, j), max(i, j), xs)
                 if anchor == glb:
                     break
         else:
@@ -751,7 +780,13 @@ def hess_abstract(xs, oracle, f, g, log=None, fast=False, cycles=1, target=0):
                 anchor = glb
                 for i in range(len(xs)):
                     for j in range(len(xs)):
-                        f(i, j, xs)
+                        key = hashlib.sha256(bytes([min(i, j)] + xs + [max(i, j)])).hexdigest()
+                        if key not in db:
+                            db.append(key)
+                            db.sort()
+                        else:
+                            continue
+                        f(min(i, j), max(i, j), xs)
                         loc = oracle(xs)
                         if loc < glb:
                             glb = loc
@@ -763,7 +798,7 @@ def hess_abstract(xs, oracle, f, g, log=None, fast=False, cycles=1, target=0):
                                 if top <= target:
                                     return opt
                         elif loc > glb:
-                            g(i, j, xs)
+                            g(min(i, j), max(i, j), xs)
                 if anchor == glb:
                     break
     return opt
@@ -894,11 +929,11 @@ def satisfy(solver, params=''):
                 lines += line.strip('v ').strip('\n') + ' '
         if len(lines) > 0:
             model = list(map(int, lines.strip(' ').split(' ')))
-            for key, value in csp.map.items():
-                for arg in csp.variables:
-                    if arg.key == key:
-                        arg.value = int(''.join(map(str, [int(int(model[abs(bit) - 1]) > 0) for bit in value[::-1]])), 2)
-                        del arg.bin[:]
+            for arg in csp.variables:
+                if isinstance(arg, Unit):
+                    ds = ''.join(map(str, [int(int(model[abs(bit) - 1]) > 0) for bit in arg.block[::-1]]))
+                    arg.value = int(ds, 2)
+                    del arg.bin[:]
             with open(csp.cnf, 'a') as file:
                 file.write(' '.join([str(-int(literal)) for literal in model]) + '\n')
                 csp.cnf_file = open(csp.cnf, 'r+')
@@ -915,8 +950,8 @@ def satisfy(solver, params=''):
 def reset():
     global csp, render
     """
-    Use this with external_satisfy on optimization rutines.
-    :param key: key of the external_satisfy problem
+    Use this with external on optimization routines.
+    :param key: key of the external problem
     :return:
     """
     import os
